nx.data.ObservableDictionary - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.data.ObservableDictionary Class

Extends nx.data.Dictionary
Module: nx.data

## Constructor

### `nx.data.ObservableDictionary`

(

- `dict`

)

#### Parameters:

- `dict` Object

- Index
- Methods
- Properties

## Item Index

### Methods

- clear
- contains
- each
- getItem
- monitor
- removeItem
- setItem
- setItems
- toArray
- toObject

### Properties

- count
- keys
- values

## Methods

### `clear`

()

Inherited from nx.data.Dictionary

### `contains`

(

- `key`

)
Boolean

Inherited from nx.data.Dictionary:

#### Parameters:

- `key` String

#### Returns:

Boolean:

### `each`

(

- `callback`
- `[context]`

)

Inherited from nx.Iterable

#### Parameters:

- `callback` Function
- `[context]` Object optional

### `getItem`

(

- `key`

)

Inherited from nx.data.Dictionary:

#### Parameters:

- `key` String

#### Returns:

:

### `monitor`

(

- `handler`

)

Apply a diff watcher, which handles each key-item-pair in the collection, to the dictionary.

#### Parameters:

- `handler` Object

  lambda(key, item) returning a rollback method

#### Returns:

unwatcher A Object with unwatch method.

### `removeItem`

(

- `key`

)

Inherited from nx.data.Dictionary

#### Parameters:

- `key` String

### `setItem`

(

- `key`
- `value`

)

Inherited from nx.data.Dictionary

#### Parameters:

- `key` String
- `value` Any

### `setItems`

(

- `dict`

)

Inherited from nx.data.Dictionary:

#### Parameters:

- `dict` Dictionary | Object

### `toArray`

() Array

Inherited from nx.Iterable

#### Returns:

Array:

### `toObject`

() Object

Inherited from nx.data.Dictionary:

#### Returns:

Object:

## Properties

### `count`

Number

Inherited from nx.Iterable

### `keys`

Iterable

Inherited from nx.data.Dictionary:

### `values`

Iterable

Inherited from nx.data.Dictionary: